#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'kcalc.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KCALC_H
#define UI_KCALC_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "kcalc_bitset.h"
#include "kcalc_button.h"
#include "kcalc_const_button.h"
#include "kcalcdisplay.h"

QT_BEGIN_NAMESPACE

class Ui_KCalculator
{
public:
    QHBoxLayout *hboxLayout;
    QVBoxLayout *vboxLayout;
    KCalcDisplay *calc_display;
    KCalcBitset *mBitset;
    QHBoxLayout *hboxLayout1;
    QRadioButton *degRadio;
    QRadioButton *radRadio;
    QRadioButton *gradRadio;
    QSpacerItem *spacerItem;
    QRadioButton *hexRadio;
    QRadioButton *decRadio;
    QRadioButton *octRadio;
    QRadioButton *binRadio;
    QHBoxLayout *hboxLayout2;
    QWidget *leftPad;
    QGridLayout *gridLayout;
    KCalcButton *pbNData;
    KCalcButton *pbHyp;
    KCalcButton *pbAND;
    KCalcButton *pbMod;
    KCalcButton *pbA;
    KCalcConstButton *pbC1;
    KCalcButton *pbMean;
    KCalcButton *pbSin;
    KCalcButton *pbOR;
    KCalcButton *pbReci;
    KCalcButton *pbB;
    KCalcConstButton *pbC2;
    KCalcButton *pbSd;
    KCalcButton *pbCos;
    KCalcButton *pbXOR;
    KCalcButton *pbFactorial;
    KCalcButton *pbC;
    KCalcConstButton *pbC3;
    KCalcButton *pbMed;
    KCalcButton *pbTan;
    KCalcButton *pbLsh;
    KCalcButton *pbSquare;
    KCalcButton *pbD;
    KCalcConstButton *pbC4;
    KCalcButton *pbDat;
    KCalcButton *pbLog;
    KCalcButton *pbRsh;
    KCalcButton *pbPower;
    KCalcButton *pbE;
    KCalcConstButton *pbC5;
    KCalcButton *pbCSt;
    KCalcButton *pbLn;
    KCalcButton *pbCmp;
    KCalcButton *pbF;
    KCalcConstButton *pbC6;
    KCalcButton *pbEE;
    KCalcButton *pbCube;
    QWidget *numericPad;
    QGridLayout *gridLayout1;
    KCalcButton *pb7;
    KCalcButton *pb8;
    KCalcButton *pb9;
    KCalcButton *pb4;
    KCalcButton *pb5;
    KCalcButton *pb6;
    KCalcButton *pb1;
    KCalcButton *pb2;
    KCalcButton *pb3;
    KCalcButton *pb0;
    KCalcButton *pbPercent;
    KCalcButton *pbDivision;
    KCalcButton *pbMultiplication;
    KCalcButton *pbMinus;
    KCalcButton *pbPlus;
    KCalcButton *pbEqual;
    KCalcButton *pbPeriod;
    QWidget *rightPad;
    QGridLayout *gridLayout2;
    KCalcButton *pbAllClear;
    KCalcButton *pbMemClear;
    KCalcButton *pbMemRecall;
    KCalcButton *pbPlusMinus;
    KCalcButton *pbParenOpen;
    KCalcButton *pbClear;
    KCalcButton *pbMemPlusMinus;
    KCalcButton *pbMemStore;
    KCalcButton *pbParenClose;
    KCalcButton *pbBackspace;
    KCalcButton *pbShift;

    void setupUi(QWidget *KCalculator)
    {
        if (KCalculator->objectName().isEmpty())
            KCalculator->setObjectName(QStringLiteral("KCalculator"));
        KCalculator->resize(701, 320);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(KCalculator->sizePolicy().hasHeightForWidth());
        KCalculator->setSizePolicy(sizePolicy);
        hboxLayout = new QHBoxLayout(KCalculator);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        hboxLayout->setSizeConstraint(QLayout::SetMinimumSize);
        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        calc_display = new KCalcDisplay(KCalculator);
        calc_display->setObjectName(QStringLiteral("calc_display"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(calc_display->sizePolicy().hasHeightForWidth());
        calc_display->setSizePolicy(sizePolicy1);
        calc_display->setFocusPolicy(Qt::StrongFocus);
        calc_display->setFrameShape(QFrame::StyledPanel);
        calc_display->setFrameShadow(QFrame::Sunken);

        vboxLayout->addWidget(calc_display);

        mBitset = new KCalcBitset(KCalculator);
        mBitset->setObjectName(QStringLiteral("mBitset"));
        sizePolicy1.setHeightForWidth(mBitset->sizePolicy().hasHeightForWidth());
        mBitset->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(mBitset);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        degRadio = new QRadioButton(KCalculator);
        degRadio->setObjectName(QStringLiteral("degRadio"));

        hboxLayout1->addWidget(degRadio);

        radRadio = new QRadioButton(KCalculator);
        radRadio->setObjectName(QStringLiteral("radRadio"));

        hboxLayout1->addWidget(radRadio);

        gradRadio = new QRadioButton(KCalculator);
        gradRadio->setObjectName(QStringLiteral("gradRadio"));

        hboxLayout1->addWidget(gradRadio);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        hboxLayout1->addItem(spacerItem);

        hexRadio = new QRadioButton(KCalculator);
        hexRadio->setObjectName(QStringLiteral("hexRadio"));

        hboxLayout1->addWidget(hexRadio);

        decRadio = new QRadioButton(KCalculator);
        decRadio->setObjectName(QStringLiteral("decRadio"));

        hboxLayout1->addWidget(decRadio);

        octRadio = new QRadioButton(KCalculator);
        octRadio->setObjectName(QStringLiteral("octRadio"));

        hboxLayout1->addWidget(octRadio);

        binRadio = new QRadioButton(KCalculator);
        binRadio->setObjectName(QStringLiteral("binRadio"));

        hboxLayout1->addWidget(binRadio);


        vboxLayout->addLayout(hboxLayout1);

        hboxLayout2 = new QHBoxLayout();
        hboxLayout2->setObjectName(QStringLiteral("hboxLayout2"));
        leftPad = new QWidget(KCalculator);
        leftPad->setObjectName(QStringLiteral("leftPad"));
        gridLayout = new QGridLayout(leftPad);
        gridLayout->setSpacing(4);
        gridLayout->setContentsMargins(2, 2, 2, 2);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        pbNData = new KCalcButton(leftPad);
        pbNData->setObjectName(QStringLiteral("pbNData"));

        gridLayout->addWidget(pbNData, 0, 0, 1, 1);

        pbHyp = new KCalcButton(leftPad);
        pbHyp->setObjectName(QStringLiteral("pbHyp"));
        pbHyp->setCheckable(true);

        gridLayout->addWidget(pbHyp, 0, 1, 1, 1);

        pbAND = new KCalcButton(leftPad);
        pbAND->setObjectName(QStringLiteral("pbAND"));

        gridLayout->addWidget(pbAND, 0, 2, 1, 1);

        pbMod = new KCalcButton(leftPad);
        pbMod->setObjectName(QStringLiteral("pbMod"));

        gridLayout->addWidget(pbMod, 0, 3, 1, 1);

        pbA = new KCalcButton(leftPad);
        pbA->setObjectName(QStringLiteral("pbA"));

        gridLayout->addWidget(pbA, 0, 4, 1, 1);

        pbC1 = new KCalcConstButton(leftPad);
        pbC1->setObjectName(QStringLiteral("pbC1"));
#ifndef UI_QT_NO_SHORTCUT
        pbC1->setShortcut(QStringLiteral("Alt+1"));
#endif // QT_NO_SHORTCUT

        gridLayout->addWidget(pbC1, 0, 5, 1, 1);

        pbMean = new KCalcButton(leftPad);
        pbMean->setObjectName(QStringLiteral("pbMean"));

        gridLayout->addWidget(pbMean, 1, 0, 1, 1);

        pbSin = new KCalcButton(leftPad);
        pbSin->setObjectName(QStringLiteral("pbSin"));

        gridLayout->addWidget(pbSin, 1, 1, 1, 1);

        pbOR = new KCalcButton(leftPad);
        pbOR->setObjectName(QStringLiteral("pbOR"));

        gridLayout->addWidget(pbOR, 1, 2, 1, 1);

        pbReci = new KCalcButton(leftPad);
        pbReci->setObjectName(QStringLiteral("pbReci"));

        gridLayout->addWidget(pbReci, 1, 3, 1, 1);

        pbB = new KCalcButton(leftPad);
        pbB->setObjectName(QStringLiteral("pbB"));

        gridLayout->addWidget(pbB, 1, 4, 1, 1);

        pbC2 = new KCalcConstButton(leftPad);
        pbC2->setObjectName(QStringLiteral("pbC2"));
#ifndef UI_QT_NO_SHORTCUT
        pbC2->setShortcut(QStringLiteral("Alt+2"));
#endif // QT_NO_SHORTCUT

        gridLayout->addWidget(pbC2, 1, 5, 1, 1);

        pbSd = new KCalcButton(leftPad);
        pbSd->setObjectName(QStringLiteral("pbSd"));

        gridLayout->addWidget(pbSd, 2, 0, 1, 1);

        pbCos = new KCalcButton(leftPad);
        pbCos->setObjectName(QStringLiteral("pbCos"));

        gridLayout->addWidget(pbCos, 2, 1, 1, 1);

        pbXOR = new KCalcButton(leftPad);
        pbXOR->setObjectName(QStringLiteral("pbXOR"));

        gridLayout->addWidget(pbXOR, 2, 2, 1, 1);

        pbFactorial = new KCalcButton(leftPad);
        pbFactorial->setObjectName(QStringLiteral("pbFactorial"));

        gridLayout->addWidget(pbFactorial, 2, 3, 1, 1);

        pbC = new KCalcButton(leftPad);
        pbC->setObjectName(QStringLiteral("pbC"));

        gridLayout->addWidget(pbC, 2, 4, 1, 1);

        pbC3 = new KCalcConstButton(leftPad);
        pbC3->setObjectName(QStringLiteral("pbC3"));
#ifndef UI_QT_NO_SHORTCUT
        pbC3->setShortcut(QStringLiteral("Alt+3"));
#endif // QT_NO_SHORTCUT

        gridLayout->addWidget(pbC3, 2, 5, 1, 1);

        pbMed = new KCalcButton(leftPad);
        pbMed->setObjectName(QStringLiteral("pbMed"));

        gridLayout->addWidget(pbMed, 3, 0, 1, 1);

        pbTan = new KCalcButton(leftPad);
        pbTan->setObjectName(QStringLiteral("pbTan"));

        gridLayout->addWidget(pbTan, 3, 1, 1, 1);

        pbLsh = new KCalcButton(leftPad);
        pbLsh->setObjectName(QStringLiteral("pbLsh"));

        gridLayout->addWidget(pbLsh, 3, 2, 1, 1);

        pbSquare = new KCalcButton(leftPad);
        pbSquare->setObjectName(QStringLiteral("pbSquare"));

        gridLayout->addWidget(pbSquare, 3, 3, 1, 1);

        pbD = new KCalcButton(leftPad);
        pbD->setObjectName(QStringLiteral("pbD"));

        gridLayout->addWidget(pbD, 3, 4, 1, 1);

        pbC4 = new KCalcConstButton(leftPad);
        pbC4->setObjectName(QStringLiteral("pbC4"));
#ifndef UI_QT_NO_SHORTCUT
        pbC4->setShortcut(QStringLiteral("Alt+4"));
#endif // QT_NO_SHORTCUT

        gridLayout->addWidget(pbC4, 3, 5, 1, 1);

        pbDat = new KCalcButton(leftPad);
        pbDat->setObjectName(QStringLiteral("pbDat"));

        gridLayout->addWidget(pbDat, 4, 0, 1, 1);

        pbLog = new KCalcButton(leftPad);
        pbLog->setObjectName(QStringLiteral("pbLog"));

        gridLayout->addWidget(pbLog, 4, 1, 1, 1);

        pbRsh = new KCalcButton(leftPad);
        pbRsh->setObjectName(QStringLiteral("pbRsh"));

        gridLayout->addWidget(pbRsh, 4, 2, 1, 1);

        pbPower = new KCalcButton(leftPad);
        pbPower->setObjectName(QStringLiteral("pbPower"));

        gridLayout->addWidget(pbPower, 4, 3, 1, 1);

        pbE = new KCalcButton(leftPad);
        pbE->setObjectName(QStringLiteral("pbE"));

        gridLayout->addWidget(pbE, 4, 4, 1, 1);

        pbC5 = new KCalcConstButton(leftPad);
        pbC5->setObjectName(QStringLiteral("pbC5"));
#ifndef UI_QT_NO_SHORTCUT
        pbC5->setShortcut(QStringLiteral("Alt+5"));
#endif // QT_NO_SHORTCUT

        gridLayout->addWidget(pbC5, 4, 5, 1, 1);

        pbCSt = new KCalcButton(leftPad);
        pbCSt->setObjectName(QStringLiteral("pbCSt"));

        gridLayout->addWidget(pbCSt, 7, 0, 1, 1);

        pbLn = new KCalcButton(leftPad);
        pbLn->setObjectName(QStringLiteral("pbLn"));

        gridLayout->addWidget(pbLn, 7, 1, 1, 1);

        pbCmp = new KCalcButton(leftPad);
        pbCmp->setObjectName(QStringLiteral("pbCmp"));

        gridLayout->addWidget(pbCmp, 7, 2, 1, 1);

        pbF = new KCalcButton(leftPad);
        pbF->setObjectName(QStringLiteral("pbF"));

        gridLayout->addWidget(pbF, 7, 4, 1, 1);

        pbC6 = new KCalcConstButton(leftPad);
        pbC6->setObjectName(QStringLiteral("pbC6"));
#ifndef UI_QT_NO_SHORTCUT
        pbC6->setShortcut(QStringLiteral("Alt+6"));
#endif // QT_NO_SHORTCUT

        gridLayout->addWidget(pbC6, 7, 5, 1, 1);

        pbEE = new KCalcButton(leftPad);
        pbEE->setObjectName(QStringLiteral("pbEE"));

        gridLayout->addWidget(pbEE, 9, 3, 1, 1);

        pbCube = new KCalcButton(leftPad);
        pbCube->setObjectName(QStringLiteral("pbCube"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(pbCube->sizePolicy().hasHeightForWidth());
        pbCube->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(pbCube, 7, 3, 1, 1);


        hboxLayout2->addWidget(leftPad);

        numericPad = new QWidget(KCalculator);
        numericPad->setObjectName(QStringLiteral("numericPad"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(numericPad->sizePolicy().hasHeightForWidth());
        numericPad->setSizePolicy(sizePolicy3);
        gridLayout1 = new QGridLayout(numericPad);
        gridLayout1->setSpacing(4);
        gridLayout1->setContentsMargins(2, 2, 2, 2);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        pb7 = new KCalcButton(numericPad);
        pb7->setObjectName(QStringLiteral("pb7"));
        sizePolicy2.setHeightForWidth(pb7->sizePolicy().hasHeightForWidth());
        pb7->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb7, 1, 0, 1, 1);

        pb8 = new KCalcButton(numericPad);
        pb8->setObjectName(QStringLiteral("pb8"));
        sizePolicy2.setHeightForWidth(pb8->sizePolicy().hasHeightForWidth());
        pb8->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb8, 1, 1, 1, 1);

        pb9 = new KCalcButton(numericPad);
        pb9->setObjectName(QStringLiteral("pb9"));
        sizePolicy2.setHeightForWidth(pb9->sizePolicy().hasHeightForWidth());
        pb9->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb9, 1, 3, 1, 1);

        pb4 = new KCalcButton(numericPad);
        pb4->setObjectName(QStringLiteral("pb4"));
        sizePolicy2.setHeightForWidth(pb4->sizePolicy().hasHeightForWidth());
        pb4->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb4, 2, 0, 1, 1);

        pb5 = new KCalcButton(numericPad);
        pb5->setObjectName(QStringLiteral("pb5"));
        sizePolicy2.setHeightForWidth(pb5->sizePolicy().hasHeightForWidth());
        pb5->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb5, 2, 1, 1, 1);

        pb6 = new KCalcButton(numericPad);
        pb6->setObjectName(QStringLiteral("pb6"));
        sizePolicy2.setHeightForWidth(pb6->sizePolicy().hasHeightForWidth());
        pb6->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb6, 2, 3, 1, 1);

        pb1 = new KCalcButton(numericPad);
        pb1->setObjectName(QStringLiteral("pb1"));
        QSizePolicy sizePolicy4(QSizePolicy::Minimum, QSizePolicy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(pb1->sizePolicy().hasHeightForWidth());
        pb1->setSizePolicy(sizePolicy4);

        gridLayout1->addWidget(pb1, 3, 0, 1, 1);

        pb2 = new KCalcButton(numericPad);
        pb2->setObjectName(QStringLiteral("pb2"));
        sizePolicy2.setHeightForWidth(pb2->sizePolicy().hasHeightForWidth());
        pb2->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb2, 3, 1, 1, 1);

        pb3 = new KCalcButton(numericPad);
        pb3->setObjectName(QStringLiteral("pb3"));
        sizePolicy2.setHeightForWidth(pb3->sizePolicy().hasHeightForWidth());
        pb3->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pb3, 3, 3, 1, 1);

        pb0 = new KCalcButton(numericPad);
        pb0->setObjectName(QStringLiteral("pb0"));
        sizePolicy4.setHeightForWidth(pb0->sizePolicy().hasHeightForWidth());
        pb0->setSizePolicy(sizePolicy4);

        gridLayout1->addWidget(pb0, 4, 0, 1, 2);

        pbPercent = new KCalcButton(numericPad);
        pbPercent->setObjectName(QStringLiteral("pbPercent"));
        sizePolicy2.setHeightForWidth(pbPercent->sizePolicy().hasHeightForWidth());
        pbPercent->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pbPercent, 0, 0, 1, 1);

        pbDivision = new KCalcButton(numericPad);
        pbDivision->setObjectName(QStringLiteral("pbDivision"));
        sizePolicy2.setHeightForWidth(pbDivision->sizePolicy().hasHeightForWidth());
        pbDivision->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pbDivision, 0, 1, 1, 1);

        pbMultiplication = new KCalcButton(numericPad);
        pbMultiplication->setObjectName(QStringLiteral("pbMultiplication"));
        sizePolicy2.setHeightForWidth(pbMultiplication->sizePolicy().hasHeightForWidth());
        pbMultiplication->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pbMultiplication, 0, 3, 1, 1);

        pbMinus = new KCalcButton(numericPad);
        pbMinus->setObjectName(QStringLiteral("pbMinus"));
        sizePolicy2.setHeightForWidth(pbMinus->sizePolicy().hasHeightForWidth());
        pbMinus->setSizePolicy(sizePolicy2);

        gridLayout1->addWidget(pbMinus, 0, 4, 1, 1);

        pbPlus = new KCalcButton(numericPad);
        pbPlus->setObjectName(QStringLiteral("pbPlus"));
        sizePolicy4.setHeightForWidth(pbPlus->sizePolicy().hasHeightForWidth());
        pbPlus->setSizePolicy(sizePolicy4);

        gridLayout1->addWidget(pbPlus, 1, 4, 2, 1);

        pbEqual = new KCalcButton(numericPad);
        pbEqual->setObjectName(QStringLiteral("pbEqual"));
        sizePolicy4.setHeightForWidth(pbEqual->sizePolicy().hasHeightForWidth());
        pbEqual->setSizePolicy(sizePolicy4);

        gridLayout1->addWidget(pbEqual, 3, 4, 2, 1);

        pbPeriod = new KCalcButton(numericPad);
        pbPeriod->setObjectName(QStringLiteral("pbPeriod"));
        sizePolicy4.setHeightForWidth(pbPeriod->sizePolicy().hasHeightForWidth());
        pbPeriod->setSizePolicy(sizePolicy4);

        gridLayout1->addWidget(pbPeriod, 4, 3, 1, 1);


        hboxLayout2->addWidget(numericPad);

        rightPad = new QWidget(KCalculator);
        rightPad->setObjectName(QStringLiteral("rightPad"));
        gridLayout2 = new QGridLayout(rightPad);
        gridLayout2->setSpacing(4);
        gridLayout2->setContentsMargins(2, 2, 2, 2);
        gridLayout2->setObjectName(QStringLiteral("gridLayout2"));
        pbAllClear = new KCalcButton(rightPad);
        pbAllClear->setObjectName(QStringLiteral("pbAllClear"));

        gridLayout2->addWidget(pbAllClear, 2, 0, 1, 1);

        pbMemClear = new KCalcButton(rightPad);
        pbMemClear->setObjectName(QStringLiteral("pbMemClear"));

        gridLayout2->addWidget(pbMemClear, 3, 1, 1, 1);

        pbMemRecall = new KCalcButton(rightPad);
        pbMemRecall->setObjectName(QStringLiteral("pbMemRecall"));

        gridLayout2->addWidget(pbMemRecall, 4, 1, 1, 1);

        pbPlusMinus = new KCalcButton(rightPad);
        pbPlusMinus->setObjectName(QStringLiteral("pbPlusMinus"));

        gridLayout2->addWidget(pbPlusMinus, 5, 0, 1, 1);

        pbParenOpen = new KCalcButton(rightPad);
        pbParenOpen->setObjectName(QStringLiteral("pbParenOpen"));

        gridLayout2->addWidget(pbParenOpen, 3, 0, 1, 1);

        pbClear = new KCalcButton(rightPad);
        pbClear->setObjectName(QStringLiteral("pbClear"));

        gridLayout2->addWidget(pbClear, 1, 0, 1, 1);

        pbMemPlusMinus = new KCalcButton(rightPad);
        pbMemPlusMinus->setObjectName(QStringLiteral("pbMemPlusMinus"));

        gridLayout2->addWidget(pbMemPlusMinus, 5, 1, 1, 1);

        pbMemStore = new KCalcButton(rightPad);
        pbMemStore->setObjectName(QStringLiteral("pbMemStore"));

        gridLayout2->addWidget(pbMemStore, 2, 1, 1, 1);

        pbParenClose = new KCalcButton(rightPad);
        pbParenClose->setObjectName(QStringLiteral("pbParenClose"));

        gridLayout2->addWidget(pbParenClose, 4, 0, 1, 1);

        pbBackspace = new KCalcButton(rightPad);
        pbBackspace->setObjectName(QStringLiteral("pbBackspace"));

        gridLayout2->addWidget(pbBackspace, 1, 1, 1, 1);

        pbShift = new KCalcButton(rightPad);
        pbShift->setObjectName(QStringLiteral("pbShift"));
        pbShift->setCheckable(true);

        gridLayout2->addWidget(pbShift, 0, 0, 1, 2);


        hboxLayout2->addWidget(rightPad);


        vboxLayout->addLayout(hboxLayout2);


        hboxLayout->addLayout(vboxLayout);

        QWidget::setTabOrder(pb0, pb1);
        QWidget::setTabOrder(pb1, pb2);
        QWidget::setTabOrder(pb2, pb3);
        QWidget::setTabOrder(pb3, pb4);
        QWidget::setTabOrder(pb4, pb5);
        QWidget::setTabOrder(pb5, pb6);
        QWidget::setTabOrder(pb6, pb7);
        QWidget::setTabOrder(pb7, pb8);
        QWidget::setTabOrder(pb8, pb9);
        QWidget::setTabOrder(pb9, pbPeriod);
        QWidget::setTabOrder(pbPeriod, pbDivision);
        QWidget::setTabOrder(pbDivision, pbMultiplication);
        QWidget::setTabOrder(pbMultiplication, pbMinus);
        QWidget::setTabOrder(pbMinus, pbPlus);
        QWidget::setTabOrder(pbPlus, pbEqual);
        QWidget::setTabOrder(pbEqual, pbPercent);
        QWidget::setTabOrder(pbPercent, pbClear);
        QWidget::setTabOrder(pbClear, pbAllClear);
        QWidget::setTabOrder(pbAllClear, pbParenOpen);
        QWidget::setTabOrder(pbParenOpen, pbParenClose);
        QWidget::setTabOrder(pbParenClose, pbPlusMinus);
        QWidget::setTabOrder(pbPlusMinus, pbMemStore);
        QWidget::setTabOrder(pbMemStore, pbMemClear);
        QWidget::setTabOrder(pbMemClear, pbMemRecall);
        QWidget::setTabOrder(pbMemRecall, pbMemPlusMinus);
        QWidget::setTabOrder(pbMemPlusMinus, pbHyp);
        QWidget::setTabOrder(pbHyp, pbSin);
        QWidget::setTabOrder(pbSin, pbCos);
        QWidget::setTabOrder(pbCos, pbTan);
        QWidget::setTabOrder(pbTan, pbLog);
        QWidget::setTabOrder(pbLog, pbLn);
        QWidget::setTabOrder(pbLn, pbMod);
        QWidget::setTabOrder(pbMod, pbReci);
        QWidget::setTabOrder(pbReci, pbFactorial);
        QWidget::setTabOrder(pbFactorial, pbSquare);
        QWidget::setTabOrder(pbSquare, pbPower);
        QWidget::setTabOrder(pbPower, pbCube);
        QWidget::setTabOrder(pbCube, pbEE);
        QWidget::setTabOrder(pbEE, pbAND);
        QWidget::setTabOrder(pbAND, pbOR);
        QWidget::setTabOrder(pbOR, pbXOR);
        QWidget::setTabOrder(pbXOR, pbLsh);
        QWidget::setTabOrder(pbLsh, pbRsh);
        QWidget::setTabOrder(pbRsh, pbCmp);
        QWidget::setTabOrder(pbCmp, pbA);
        QWidget::setTabOrder(pbA, pbB);
        QWidget::setTabOrder(pbB, pbC);
        QWidget::setTabOrder(pbC, pbD);
        QWidget::setTabOrder(pbD, pbE);
        QWidget::setTabOrder(pbE, pbF);
        QWidget::setTabOrder(pbF, pbC1);
        QWidget::setTabOrder(pbC1, pbC2);
        QWidget::setTabOrder(pbC2, pbC3);
        QWidget::setTabOrder(pbC3, pbC4);
        QWidget::setTabOrder(pbC4, pbC5);
        QWidget::setTabOrder(pbC5, pbC6);
        QWidget::setTabOrder(pbC6, pbNData);
        QWidget::setTabOrder(pbNData, pbMean);
        QWidget::setTabOrder(pbMean, pbSd);
        QWidget::setTabOrder(pbSd, pbMed);
        QWidget::setTabOrder(pbMed, pbDat);
        QWidget::setTabOrder(pbDat, pbCSt);
        QWidget::setTabOrder(pbCSt, degRadio);
        QWidget::setTabOrder(degRadio, radRadio);
        QWidget::setTabOrder(radRadio, gradRadio);
        QWidget::setTabOrder(gradRadio, hexRadio);
        QWidget::setTabOrder(hexRadio, decRadio);
        QWidget::setTabOrder(decRadio, octRadio);
        QWidget::setTabOrder(octRadio, binRadio);
        QWidget::setTabOrder(binRadio, calc_display);

        retranslateUi(KCalculator);

        QMetaObject::connectSlotsByName(KCalculator);
    } // setupUi

    void retranslateUi(QWidget *KCalculator)
    {
        KCalculator->setWindowTitle(tr2i18n("KCalc", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        mBitset->setToolTip(tr2i18n("Click on a Bit to toggle it.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        degRadio->setText(tr2i18n("Deg", Q_NULLPTR));
        radRadio->setText(tr2i18n("Rad", Q_NULLPTR));
        gradRadio->setText(tr2i18n("Grad", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        hexRadio->setToolTip(tr2i18n("Switch base to hexadecimal.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        hexRadio->setText(tr2i18n("He&x", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        decRadio->setToolTip(tr2i18n("Switch base to decimal.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        decRadio->setText(tr2i18n("&Dec", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        octRadio->setToolTip(tr2i18n("Switch base to octal.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        octRadio->setText(tr2i18n("&Oct", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        binRadio->setToolTip(tr2i18n("Switch base to binary.", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        binRadio->setText(tr2i18n("&Bin", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbNData->setToolTip(tr2i18n("Number of data entered", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbNData->setText(tr2i18n("N", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbHyp->setToolTip(tr2i18n("Hyperbolic mode", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbHyp->setText(tr2i18n("Hyp", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbHyp->setShortcut(tr2i18n("H", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbAND->setToolTip(tr2i18n("Bitwise AND", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbAND->setText(tr2i18n("AND", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMod->setToolTip(tr2i18n("Modulo", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMod->setText(tr2i18n("Mod", Q_NULLPTR));
        pbA->setText(tr2i18n("A", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbA->setShortcut(tr2i18n("A", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pbC1->setText(tr2i18n("C1", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMean->setToolTip(tr2i18n("Mean", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMean->setText(tr2i18n("Mea", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbSin->setToolTip(tr2i18n("Sine", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbSin->setText(tr2i18n("Sin", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbSin->setShortcut(tr2i18n("S", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbOR->setToolTip(tr2i18n("Bitwise OR", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbOR->setText(tr2i18n("OR", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbReci->setToolTip(tr2i18n("Reciprocal", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbReci->setText(tr2i18n("1/X", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbReci->setShortcut(tr2i18n("R", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pbB->setText(tr2i18n("B", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbB->setShortcut(tr2i18n("B", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pbC2->setText(tr2i18n("C2", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbSd->setToolTip(tr2i18n("Standard deviation", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbSd->setText(tr2i18n("SD", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbCos->setToolTip(tr2i18n("Cosine", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbCos->setText(tr2i18n("Cos", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbCos->setShortcut(tr2i18n("C", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbXOR->setToolTip(tr2i18n("Bitwise XOR", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbXOR->setText(tr2i18n("XOR", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbFactorial->setToolTip(tr2i18n("Factorial", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbFactorial->setText(tr2i18n("x!", Q_NULLPTR));
        pbC->setText(tr2i18n("C", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbC->setShortcut(tr2i18n("C", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pbC3->setText(tr2i18n("C3", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMed->setToolTip(tr2i18n("Median", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMed->setText(tr2i18n("Med", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbTan->setToolTip(tr2i18n("Tangent", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbTan->setText(tr2i18n("Tan", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbTan->setShortcut(tr2i18n("T", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbLsh->setToolTip(tr2i18n("Left bit shift", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbLsh->setText(tr2i18n("Lsh", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbSquare->setToolTip(tr2i18n("Square", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbSquare->setText(tr2i18n("x2", Q_NULLPTR));
        pbD->setText(tr2i18n("D", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbD->setShortcut(tr2i18n("D", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pbC4->setText(tr2i18n("C4", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbDat->setToolTip(tr2i18n("Enter data", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbDat->setText(tr2i18n("Dat", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbDat->setShortcut(tr2i18n("D", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbLog->setToolTip(tr2i18n("Logarithm to base 10", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbLog->setText(tr2i18n("Log", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbLog->setShortcut(tr2i18n("L", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbRsh->setToolTip(tr2i18n("Right bit shift", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbRsh->setText(tr2i18n("Rsh", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbPower->setToolTip(tr2i18n("x to the power of y", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbPower->setText(tr2i18n("pow", Q_NULLPTR));
        pbE->setText(tr2i18n("E", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbE->setShortcut(tr2i18n("E", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pbC5->setText(tr2i18n("C5", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbCSt->setToolTip(tr2i18n("Clear data store", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbCSt->setText(tr2i18n("CSt", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbLn->setToolTip(tr2i18n("Natural log", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbLn->setText(tr2i18n("Ln", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbLn->setShortcut(tr2i18n("N", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbCmp->setToolTip(tr2i18n("One's complement", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbCmp->setText(tr2i18n("Cmp", Q_NULLPTR));
        pbF->setText(tr2i18n("F", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbF->setShortcut(tr2i18n("F", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pbC6->setText(tr2i18n("C6", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbEE->setToolTip(tr2i18n("Exponent", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbEE->setText(tr2i18n("EXP", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbEE->setShortcut(tr2i18n("E", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbCube->setToolTip(tr2i18n("Cube", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbCube->setText(tr2i18n("x3", Q_NULLPTR));
        pb7->setText(tr2i18n("7", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb7->setShortcut(tr2i18n("7", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb8->setText(tr2i18n("8", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb8->setShortcut(tr2i18n("8", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb9->setText(tr2i18n("9", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb9->setShortcut(tr2i18n("9", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb4->setText(tr2i18n("4", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb4->setShortcut(tr2i18n("4", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb5->setText(tr2i18n("5", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb5->setShortcut(tr2i18n("5", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb6->setText(tr2i18n("6", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb6->setShortcut(tr2i18n("6", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb1->setText(tr2i18n("1", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb1->setShortcut(tr2i18n("1", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb2->setText(tr2i18n("2", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb2->setShortcut(tr2i18n("2", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb3->setText(tr2i18n("3", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb3->setShortcut(tr2i18n("3", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
        pb0->setText(tr2i18n("0", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pb0->setShortcut(tr2i18n("0", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbPercent->setToolTip(tr2i18n("Percent", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbPercent->setText(tr2i18n("%", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbDivision->setToolTip(tr2i18n("Division", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbDivision->setText(tr2i18n("\303\267", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMultiplication->setToolTip(tr2i18n("Multiplication", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMultiplication->setText(tr2i18n("\303\227", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMinus->setToolTip(tr2i18n("Minus", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMinus->setText(tr2i18n("\342\210\222", "- calculator button"));
#ifndef UI_QT_NO_TOOLTIP
        pbPlus->setToolTip(tr2i18n("Plus", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbPlus->setText(tr2i18n("+", "+ calculator button"));
#ifndef UI_QT_NO_TOOLTIP
        pbEqual->setToolTip(tr2i18n("Result", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbEqual->setText(tr2i18n("=", "= calculator button"));
#ifndef UI_QT_NO_TOOLTIP
        pbPeriod->setToolTip(tr2i18n("Decimal point", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbPeriod->setText(tr2i18n(".", ". calculator button"));
#ifndef UI_QT_NO_TOOLTIP
        pbAllClear->setToolTip(tr2i18n("Clear all", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbAllClear->setText(tr2i18n("AC", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMemClear->setToolTip(tr2i18n("Memory clear", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMemClear->setText(tr2i18n("MC", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMemRecall->setToolTip(tr2i18n("Memory recall", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMemRecall->setText(tr2i18n("MR", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbPlusMinus->setToolTip(tr2i18n("Change sign", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbPlusMinus->setText(tr2i18n("+/\342\210\222", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbParenOpen->setToolTip(tr2i18n("Open parenthesis", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbParenOpen->setText(tr2i18n("(", "( calculator button"));
#ifndef UI_QT_NO_TOOLTIP
        pbClear->setToolTip(tr2i18n("Clear", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbClear->setText(tr2i18n("C", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMemPlusMinus->setToolTip(tr2i18n("Add to memory", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMemPlusMinus->setText(tr2i18n("M+", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbMemStore->setToolTip(tr2i18n("Memory store", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbMemStore->setText(tr2i18n("MS", Q_NULLPTR));
#ifndef UI_QT_NO_TOOLTIP
        pbParenClose->setToolTip(tr2i18n("Close parenthesis", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbParenClose->setText(tr2i18n(")", ") calculator button"));
        pbBackspace->setText(tr2i18n("\342\206\220", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbBackspace->setShortcut(tr2i18n("Backspace", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
#ifndef UI_QT_NO_TOOLTIP
        pbShift->setToolTip(tr2i18n("Second button function", Q_NULLPTR));
#endif // QT_NO_TOOLTIP
        pbShift->setText(tr2i18n("Shift", Q_NULLPTR));
#ifndef UI_QT_NO_SHORTCUT
        pbShift->setShortcut(tr2i18n("Ctrl+2", Q_NULLPTR));
#endif // QT_NO_SHORTCUT
    } // retranslateUi

};

namespace Ui {
    class KCalculator: public Ui_KCalculator {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KCALC_H

